pub struct ConfigFile {
pub verify: VerifyConfig,
pub stamp: StampConfig,
pub telemetry: TelemetryConfig,
pub lint: LintConfig,
pub corpus: CorpusConfig,
pub doc: DocConfig,
pub index: IndexConfig,
pub canon: CanonConfig,
}Expand description
Top-level aristo.toml document. Every field defaults; an empty
file produces a ConfigFile with each section at its default.
Fields
verify: VerifyConfigstamp: StampConfigtelemetry: TelemetryConfiglint: LintConfigcorpus: CorpusConfigdoc: DocConfigindex: IndexConfigcanon: CanonConfigTrait Implementations
Sourceimpl Clone for ConfigFile
impl Clone for ConfigFile
Sourcefn clone(&self) -> ConfigFile
fn clone(&self) -> ConfigFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigFile
impl Debug for ConfigFile
Sourceimpl Default for ConfigFile
impl Default for ConfigFile
Sourcefn default() -> ConfigFile
fn default() -> ConfigFile
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ConfigFile
impl<'de> Deserialize<'de> for ConfigFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigFile
impl JsonSchema for ConfigFile
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigFile
impl PartialEq for ConfigFile
Sourcefn eq(&self, other: &ConfigFile) -> bool
fn eq(&self, other: &ConfigFile) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ConfigFile
impl Serialize for ConfigFile
impl Eq for ConfigFile
impl StructuralPartialEq for ConfigFile