pub struct LintRuleConfig {
pub severity: Option<Severity>,
pub threshold: Option<u32>,
pub auto_fix: Option<bool>,
pub pattern: Option<String>,
pub message: Option<String>,
}Expand description
Per-rule lint configuration. All fields are optional; each individual
rule consumes the subset that applies to it (e.g., pattern +
message are only meaningful for the custom-regex rule).
Fields
severity: Option<Severity>threshold: Option<u32>auto_fix: Option<bool>pattern: Option<String>message: Option<String>Trait Implementations
Sourceimpl Clone for LintRuleConfig
impl Clone for LintRuleConfig
Sourcefn clone(&self) -> LintRuleConfig
fn clone(&self) -> LintRuleConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LintRuleConfig
impl Debug for LintRuleConfig
Sourceimpl Default for LintRuleConfig
impl Default for LintRuleConfig
Sourcefn default() -> LintRuleConfig
fn default() -> LintRuleConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for LintRuleConfig
impl<'de> Deserialize<'de> for LintRuleConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LintRuleConfig
Sourceimpl JsonSchema for LintRuleConfig
impl JsonSchema for LintRuleConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LintRuleConfig
impl PartialEq for LintRuleConfig
Sourceimpl Serialize for LintRuleConfig
impl Serialize for LintRuleConfig
impl StructuralPartialEq for LintRuleConfig