pub struct VerifyConfig {
pub default_method: Option<VerifyMethod>,
pub cache: VerifyCacheConfig,
}Fields
default_method: Option<VerifyMethod>Resolves verify = true on annotations to a concrete method.
None means “use the per-tier default” (free → "test",
paid → "full" per G1).
cache: VerifyCacheConfigTrait Implementations
Sourceimpl Clone for VerifyConfig
impl Clone for VerifyConfig
Sourcefn clone(&self) -> VerifyConfig
fn clone(&self) -> VerifyConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifyConfig
impl Debug for VerifyConfig
Sourceimpl Default for VerifyConfig
impl Default for VerifyConfig
Sourcefn default() -> VerifyConfig
fn default() -> VerifyConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for VerifyConfig
impl<'de> Deserialize<'de> for VerifyConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VerifyConfig
impl JsonSchema for VerifyConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerifyConfig
impl PartialEq for VerifyConfig
Sourcefn eq(&self, other: &VerifyConfig) -> bool
fn eq(&self, other: &VerifyConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VerifyConfig
impl Serialize for VerifyConfig
impl Eq for VerifyConfig
impl StructuralPartialEq for VerifyConfig